# Poseidon API: Simple RESTful API for querying information about nodes that Poseidon detects.

> Software Defined Network Situational Awareness

See the [GitHub home page](https://github.com/IQTLabs/poseidon)
